searchNodes=[{"ref":"FileSize.Ecto.Bit.html","title":"FileSize.Ecto.Bit","type":"module","doc":"An Ecto type that represents a file size in bits. The value is stored as integer in the database. Example defmodule MySchema do use Ecto.Schema schema &quot;my_table&quot; do field :file_size, FileSize.Ecto.Bit end end"},{"ref":"FileSize.Ecto.Byte.html","title":"FileSize.Ecto.Byte","type":"module","doc":"An Ecto type that represents a file size in bytes. The value is stored as integer in the database. Example defmodule MySchema do use Ecto.Schema schema &quot;my_table&quot; do field :file_size, FileSize.Ecto.Byte end end"},{"ref":"FileSize.Ecto.BitWithUnit.html","title":"FileSize.Ecto.BitWithUnit","type":"module","doc":"An Ecto type that represents a file size in bits, supporting storage of different units. The value is stored as map in the database (i.e. jsonb when using PostgreSQL). Example defmodule MySchema do use Ecto.Schema schema &quot;my_table&quot; do field :file_size, FileSize.Ecto.BitWithUnit end end"},{"ref":"FileSize.Ecto.ByteWithUnit.html","title":"FileSize.Ecto.ByteWithUnit","type":"module","doc":"An Ecto type that represents a file size in bytes, supporting storage of different units. The value is stored as map in the database (i.e. jsonb when using PostgreSQL). Example defmodule MySchema do use Ecto.Schema schema &quot;my_table&quot; do field :file_size, FileSize.Ecto.ByteWithUnit end end"},{"ref":"readme.html","title":"File Size for Ecto","type":"extras","doc":"File Size for Ecto Provides types for file sizes that you can use in your Ecto schemata. This library uses file_size under the hood that brings a file size parser, formatter and allows calculation and comparison of file sizes with different units."},{"ref":"readme.html#prerequisites","title":"File Size for Ecto - Prerequisites","type":"extras","doc":"Erlang 20 or greater Elixir 1.8 or greater"},{"ref":"readme.html#installation","title":"File Size for Ecto - Installation","type":"extras","doc":"If available in Hex, the package can be installed by adding file_size_ecto to your list of dependencies in mix.exs: def deps do [ {:file_size_ecto, &quot;~&gt; 2.0&quot;} ] end Documentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/file_size_ecto."},{"ref":"readme.html#usage","title":"File Size for Ecto - Usage","type":"extras","doc":"Without Unit The following unit-less types are available: FileSize.Ecto.Bit FileSize.Ecto.Byte Write a migration to add or update your file size field. You can use :integer or :bigint as types. If you expect very large file sizes, :bigint is recommended of course. defmodule MyProject.Migrations.AddFileSizeToMyTable use Ecto.Migration def up do alter table(:my_table) do add :file_size, :bigint end end end Update your schema: defmodule MySchema do use Ecto.Schema schema &quot;my_table&quot; do # ... field :file_size, FileSize.Ecto.Byte end end You can store your file size like this: record = Repo.get(MySchema, 123) updated_record = record |&gt; Echo.Changeset.change(file_size: FileSize.new(2, :mb)) |&gt; Repo.update!() updated_record.file_size # =&gt; #FileSize&lt;&quot;2000000 B&quot;&gt; Or, when working with user input: updated_record record |&gt; Echo.Changeset.cast(%{file_size: &quot;4 KiB&quot;}, [:file_size]) |&gt; Repo.update!() updated_record.file_size # =&gt; #FileSize&lt;&quot;4096 B&quot;&gt; Note that the file size is always converted to the base unit (bit or byte) when storing it in the database, because no unit information is available. Read the next section if you want to find out how to store the size unit together with the value. With Unit The following types with units are available: FileSize.Ecto.BitWithUnit FileSize.Ecto.ByteWithUnit Write a migration to add or update your file size field. The value is stored in a :map field. This map contains the as bits or bytes and the unit. defmodule MyProject.Migrations.AddFileSizeToMyTable use Ecto.Migration def up do alter table(:my_table) do add :file_size, :map end end end Update your schema: defmodule MySchema do use Ecto.Schema schema &quot;my_table&quot; do # ... field :file_size, FileSize.Ecto.ByteWithUnit end end You can store your file size like this: record = Repo.get(MySchema, 123) updated_record = record |&gt; Echo.Changeset.change(file_size: FileSize.new(2, :mb)) |&gt; Repo.update!() updated_record.file_size # =&gt; #FileSize&lt;&quot;2 MB&quot;&gt; Or, when working with user input: updated_record record |&gt; Echo.Changeset.cast(%{file_size: &quot;4 KiB&quot;}, [:file_size]) |&gt; Repo.update!() updated_record.file_size # =&gt; #FileSize&lt;&quot;4 KiB&quot;&gt;"},{"ref":"readme.html#docs","title":"File Size for Ecto - Docs","type":"extras","doc":"Documentation is available on HexDocs."}]